#include <algorithm>
#include <boost/multi_index_container.hpp>
#include <boost/multi_index/composite_key.hpp>
#include <boost/multi_index/member.hpp>
#include <boost/multi_index/ordered_index.hpp>
#include <string>

struct record
{
  record(const std::string& domain,const std::string& path):
    domain(domain),path(path)
  {}
  
  std::string domain;
  std::string path;
};

struct reverse_str_less
{
  bool operator()(const std::string& x,const std::string& y)const
  {
    return std::lexicographical_compare(
      x.rbegin(),x.rend(),y.rbegin(),y.rend()); 
  }
};

using namespace boost::multi_index;

typedef multi_index_container<
  record,
  indexed_by<
    ordered_unique<
      composite_key<
        record,
        member<record,std::string,&record::domain>,
        member<record,std::string,&record::path>
      >,
      composite_key_compare<
        reverse_str_less,
        std::less<std::string>
      >
    >
  >
> multi_index_t;

int main()
{
  multi_index_t m;
  m.insert(record("google.com","/abc"));
}